@@ -100,7 +100,7 @@ class Worker(object):
                     self.commands.extend(local)
                     return self.application.enqueue(self._next_command)
             except Exception, ex:
-                self._fail(ex)
+                return self._fail(ex)
 
         self._success()
 
@@ -136,7 +136,9 @@ class Worker(object):
         self.commands = None
         self.application.enqueue(self._work)
 
-    def _fail(self, reason=None):
+    def _fail(self, reason):
+        print "ERROR:", reason
+
         self.application.db.update("UPDATE push SET status = ?, completed = DATETIME('NOW') WHERE id = ?",
                                    STATUS_FAILED, self.task["push_id"])
         self._complete()
